==> gpe-applauncher-0.9.tar.bz2: gpe-applauncher-0.9/gpe-applauncher.h <==
/*
 * gpe-applauncher
 *
 * Application launcher for GPE Phone Edition.
 * 
 * (c) kernel concepts 2006
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GPE_APPLAUNCHER_H
#define _GPE_APPLAUNCHER_H

GtkWidget *applauncher_get_softkey_area (void);
GtkWidget *applauncher_get_main_window (void);
void render_bg (const char* filename, GtkWidget *widget);
void set_background_pixmap (const gchar *filename, GtkWidget *widget);
void set_background_colour (GdkColor colour, GtkWidget *widget);
void set_icon_size (gint size);
GdkPixbuf* load_icon_scaled (const gchar *iconname, gint size);
void set_gpe_theme (const gchar *theme);
void popup_softkey_menu (gint nr);
void applauncher_present (gint tab);
void applauncher_toggle_home (void);

#define THEME_PREFIX      "/desktop/theme/" 
#define KEY_CURRENT_THEME "/desktop/theme/currenttheme"
#define KEY_RESOURCE_PATH "/desktop/theme/resourcepath"
#define DEFAULT_THEME     "default"
#define DEFAULT_RESOURCE_PATH PREFIX "/share/gpe/pixmaps/"
#define DEFAULT_PIXMAP_PATH PREFIX "/share/pixmaps/"

int setting; /* doesn't that hurt? */

#define PANEL_SMALL 24
#define PANEL_LARGE 48

#define TAB_HOMESCREEN   0
#define TAB_APPLICATIONS 1

#endif

==> gpe-applauncher-0.10.tar.bz2: gpe-applauncher-0.10/gpe-applauncher.h <==
/*
 * gpe-applauncher
 *
 * Application launcher for GPE Phone Edition.
 * 
 * (c) kernel concepts 2006
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GPE_APPLAUNCHER_H
#define _GPE_APPLAUNCHER_H

GtkWidget *applauncher_get_softkey_area (void);
GtkWidget *applauncher_get_main_window (void);
void render_bg (const char* filename, GtkWidget *widget);
void set_background_pixmap (const gchar *filename, GtkWidget *widget);
void set_background_colour (GdkColor colour, GtkWidget *widget);
void set_icon_size (gint size);
GdkPixbuf* load_icon_scaled (const gchar *iconname, gint size);
void set_gpe_theme (const gchar *theme);
void popup_softkey_menu (gint nr);
void applauncher_present (gint tab);
void applauncher_toggle_home (void);

#define THEME_PREFIX      "/desktop/theme/" 
#define KEY_CURRENT_THEME "/desktop/theme/currenttheme"
#define KEY_RESOURCE_PATH "/desktop/theme/resourcepath"
#define DEFAULT_THEME     "default"
#define DEFAULT_RESOURCE_PATH PREFIX "/share/themes/"
#define DEFAULT_PIXMAP_PATH PREFIX "/share/pixmaps/"

int setting; /* doesn't that hurt? */

#define PANEL_SMALL 24
#define PANEL_LARGE 48

#define TAB_HOMESCREEN   0
#define TAB_APPLICATIONS 1

#endif
